<?php

use think\migration\Seeder;

class PermissionSeed extends Seeder
{
    /**
     * Run Method.
     *
     * Write your database seeder using this method.
     *
     * More information on writing seeders is available here:
     * http://docs.phinx.org/en/latest/seeding.html
     */
    public function run()
    {
        $this->roles();
        $this->createPermissions();
    }

    protected function roles()
    {
        \catchAdmin\permissions\model\Roles::create([
            'role_name' => '超级管理员',
            'description' => 'super user',
            'creator_id' => 1,
        ]);
        \think\facade\Db::name( 'user_has_roles')->insert([
           'role_id' => 1,
           'uid' => 1,
        ]);

        \think\facade\Db::name('role_has_permissions')->insertAll($this->getRolePermissions());
    }


    protected function createPermissions()
    {
        foreach ($this->getPermissions() as $permission) {
            \catchAdmin\permissions\model\Permissions::create($permission);
        }
    }



    protected function getPermissions()
    {
        return [
     0 =>
         array (
             'id' => 1,
             'permission_name' => 'Dashboard',
             'parent_id' => 0,
             'route' => '/dashboard',
             'icon' => 'home',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'index@dashboard',
             'component' => 'userLayout',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 1000,
             'created_at' => '2020-04-21 17:27:07',
             'updated_at' => '2020-04-21 19:10:37',
             'deleted_at' => 0,
         ),
     1 =>
         array (
             'id' => 2,
             'permission_name' => '主页',
             'parent_id' => 1,
             'route' => '/dashboard/workplac',
             'icon' => '',
             'module' => 'index',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'index@index',
             'component' => 'workplace',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 1,
             'created_at' => '2020-04-21 17:28:46',
             'updated_at' => '2020-04-21 17:34:25',
             'deleted_at' => 0,
         ),
     2 =>
         array (
             'id' => 3,
             'permission_name' => '权限管理',
             'parent_id' => 0,
             'route' => '/permissions',
             'icon' => 'appstore',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@index',
             'component' => 'pageView',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 100,
             'created_at' => '2020-04-21 17:30:55',
             'updated_at' => '2020-04-21 19:10:37',
             'deleted_at' => 0,
         ),
     3 =>
         array (
             'id' => 4,
             'permission_name' => '用户管理',
             'parent_id' => 3,
             'route' => '/permissions/users',
             'icon' => 'user',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@index',
             'component' => 'users',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 10,
             'created_at' => '2020-04-21 17:33:17',
             'updated_at' => '2020-04-21 19:08:57',
             'deleted_at' => 0,
         ),
     4 =>
         array (
             'id' => 5,
             'permission_name' => '列表',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@list',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:34:07',
             'updated_at' => '2020-04-21 17:34:07',
             'deleted_at' => 0,
         ),
     5 =>
         array (
             'id' => 6,
             'permission_name' => '创建',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user:create',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:34:56',
             'updated_at' => '2020-04-21 17:34:56',
             'deleted_at' => 0,
         ),
     6 =>
         array (
             'id' => 7,
             'permission_name' => '保存',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:35:21',
             'updated_at' => '2020-04-21 17:35:21',
             'deleted_at' => 0,
         ),
     7 =>
         array (
             'id' => 8,
             'permission_name' => '查看',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@edit',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:35:42',
             'updated_at' => '2020-04-21 17:35:42',
             'deleted_at' => 0,
         ),
     8 =>
         array (
             'id' => 9,
             'permission_name' => '更新',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@update',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:36:02',
             'updated_at' => '2020-04-21 17:36:02',
             'deleted_at' => 0,
         ),
     9 =>
         array (
             'id' => 10,
             'permission_name' => '删除',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:37:21',
             'updated_at' => '2020-04-21 17:37:21',
             'deleted_at' => 0,
         ),
     10 =>
         array (
             'id' => 11,
             'permission_name' => '禁用',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@switchStatus',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:37:56',
             'updated_at' => '2020-04-21 17:37:56',
             'deleted_at' => 0,
         ),
     11 =>
         array (
             'id' => 12,
             'permission_name' => '恢复',
             'parent_id' => 4,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'user@recover',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:38:21',
             'updated_at' => '2020-04-21 17:38:21',
             'deleted_at' => 0,
         ),
     12 =>
         array (
             'id' => 13,
             'permission_name' => '角色管理',
             'parent_id' => 3,
             'route' => '/permissions/roles',
             'icon' => 'usergroup-add',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role:index',
             'component' => 'roles',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 9,
             'created_at' => '2020-04-21 17:38:59',
             'updated_at' => '2020-04-21 19:09:02',
             'deleted_at' => 0,
         ),
     13 =>
         array (
             'id' => 14,
             'permission_name' => '列表',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@list',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:39:44',
             'updated_at' => '2020-04-21 17:39:44',
             'deleted_at' => 0,
         ),
     14 =>
         array (
             'id' => 15,
             'permission_name' => '创建',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@create',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:40:07',
             'updated_at' => '2020-04-21 17:40:07',
             'deleted_at' => 0,
         ),
     15 =>
         array (
             'id' => 16,
             'permission_name' => '保存',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:40:21',
             'updated_at' => '2020-04-21 17:40:21',
             'deleted_at' => 0,
         ),
     16 =>
         array (
             'id' => 17,
             'permission_name' => '查看',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@edit',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:40:40',
             'updated_at' => '2020-04-21 17:40:40',
             'deleted_at' => 0,
         ),
     17 =>
         array (
             'id' => 18,
             'permission_name' => '更新',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@update',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:40:58',
             'updated_at' => '2020-04-21 17:40:58',
             'deleted_at' => 0,
         ),
     18 =>
         array (
             'id' => 19,
             'permission_name' => '删除',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:41:10',
             'updated_at' => '2020-04-21 17:41:10',
             'deleted_at' => 0,
         ),
     19 =>
         array (
             'id' => 20,
             'permission_name' => '权限获取',
             'parent_id' => 13,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'role@getPermissions',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:41:34',
             'updated_at' => '2020-04-21 17:41:34',
             'deleted_at' => 0,
         ),
     20 =>
         array (
             'id' => 21,
             'permission_name' => '菜单管理',
             'parent_id' => 3,
             'route' => '/permissions/rules',
             'icon' => 'build',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@index',
             'component' => 'rules',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 8,
             'created_at' => '2020-04-21 17:42:27',
             'updated_at' => '2020-04-21 19:09:09',
             'deleted_at' => 0,
         ),
     21 =>
         array (
             'id' => 22,
             'permission_name' => '列表',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@index',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:43:25',
             'updated_at' => '2020-04-21 17:43:25',
             'deleted_at' => 0,
         ),
     22 =>
         array (
             'id' => 23,
             'permission_name' => '创建',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@create',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:43:52',
             'updated_at' => '2020-04-21 17:43:52',
             'deleted_at' => 0,
         ),
     23 =>
         array (
             'id' => 24,
             'permission_name' => '保存',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:44:10',
             'updated_at' => '2020-04-21 17:44:10',
             'deleted_at' => 0,
         ),
     24 =>
         array (
             'id' => 25,
             'permission_name' => '查看',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@edit',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:44:33',
             'updated_at' => '2020-04-21 17:44:33',
             'deleted_at' => 0,
         ),
     25 =>
         array (
             'id' => 26,
             'permission_name' => '更新',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@update',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:44:44',
             'updated_at' => '2020-04-21 17:44:44',
             'deleted_at' => 0,
         ),
     26 =>
         array (
             'id' => 27,
             'permission_name' => '删除',
             'parent_id' => 21,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'permission@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:44:56',
             'updated_at' => '2020-04-21 17:44:56',
             'deleted_at' => 0,
         ),
     27 =>
         array (
             'id' => 28,
             'permission_name' => '系统管理',
             'parent_id' => 0,
             'route' => 'system',
             'icon' => 'bar-chart',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'system',
             'component' => 'pageView',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 1,
             'created_at' => '2020-04-21 17:45:49',
             'updated_at' => '2020-04-21 19:10:37',
             'deleted_at' => 0,
         ),
     28 =>
         array (
             'id' => 29,
             'permission_name' => '部门管理',
             'parent_id' => 3,
             'route' => '/permissions/departments',
             'icon' => 'desktop',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'departments',
             'component' => 'departments',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 7,
             'created_at' => '2020-04-21 17:48:08',
             'updated_at' => '2020-04-21 17:52:08',
             'deleted_at' => 0,
         ),
     29 =>
         array (
             'id' => 30,
             'permission_name' => '列表',
             'parent_id' => 29,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'department@index',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:48:49',
             'updated_at' => '2020-04-21 17:48:49',
             'deleted_at' => 0,
         ),
     30 =>
         array (
             'id' => 31,
             'permission_name' => '保存',
             'parent_id' => 29,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'department@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:49:08',
             'updated_at' => '2020-04-21 17:49:08',
             'deleted_at' => 0,
         ),
     31 =>
         array (
             'id' => 32,
             'permission_name' => '更新',
             'parent_id' => 29,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'department@update',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:49:39',
             'updated_at' => '2020-04-21 17:49:39',
             'deleted_at' => 0,
         ),
     32 =>
         array (
             'id' => 33,
             'permission_name' => '删除',
             'parent_id' => 29,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'department@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:49:52',
             'updated_at' => '2020-04-21 17:49:52',
             'deleted_at' => 0,
         ),
     33 =>
         array (
             'id' => 34,
             'permission_name' => '岗位管理',
             'parent_id' => 3,
             'route' => '/permissions/jobs',
             'icon' => 'skin',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'jobs',
             'component' => 'jobs',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 1,
             'created_at' => '2020-04-21 17:51:47',
             'updated_at' => '2020-04-21 17:51:47',
             'deleted_at' => 0,
         ),
     34 =>
         array (
             'id' => 35,
             'permission_name' => '列表',
             'parent_id' => 34,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'job@index',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:52:37',
             'updated_at' => '2020-04-21 17:52:37',
             'deleted_at' => 0,
         ),
     35 =>
         array (
             'id' => 36,
             'permission_name' => '保存',
             'parent_id' => 34,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'job@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:52:54',
             'updated_at' => '2020-04-21 17:52:54',
             'deleted_at' => 0,
         ),
     36 =>
         array (
             'id' => 37,
             'permission_name' => '更新',
             'parent_id' => 34,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'job@update',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:53:05',
             'updated_at' => '2020-04-21 17:53:05',
             'deleted_at' => 0,
         ),
     37 =>
         array (
             'id' => 38,
             'permission_name' => '删除',
             'parent_id' => 34,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'job@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:53:14',
             'updated_at' => '2020-04-21 17:53:14',
             'deleted_at' => 0,
         ),
     38 =>
         array (
             'id' => 39,
             'permission_name' => '获取全部',
             'parent_id' => 34,
             'route' => '',
             'icon' => '',
             'module' => 'permissions',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'job@getAll',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:53:38',
             'updated_at' => '2020-04-21 17:53:38',
             'deleted_at' => 0,
         ),
     39 =>
         array (
             'id' => 40,
             'permission_name' => '数据字典',
             'parent_id' => 28,
             'route' => '/system/database',
             'icon' => 'hdd',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'datadictory',
             'component' => 'database',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 8,
             'created_at' => '2020-04-21 17:58:07',
             'updated_at' => '2020-04-21 19:03:22',
             'deleted_at' => 0,
         ),
     40 =>
         array (
             'id' => 41,
             'permission_name' => '查看',
             'parent_id' => 40,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'datadictionary@view',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 17:58:33',
             'updated_at' => '2020-04-21 17:58:41',
             'deleted_at' => 0,
         ),
     41 =>
         array (
             'id' => 42,
             'permission_name' => '列表',
             'parent_id' => 40,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'datadictionary@tables',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 10,
             'created_at' => '2020-04-21 17:59:33',
             'updated_at' => '2020-04-21 17:59:33',
             'deleted_at' => 0,
         ),
     42 =>
         array (
             'id' => 43,
             'permission_name' => '优化',
             'parent_id' => 40,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'datadictionary@optimize',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 18:00:01',
             'updated_at' => '2020-04-21 18:00:01',
             'deleted_at' => 0,
         ),
     43 =>
         array (
             'id' => 44,
             'permission_name' => '备份',
             'parent_id' => 40,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'optimize@backup',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 18:00:17',
             'updated_at' => '2020-04-21 18:00:17',
             'deleted_at' => 0,
         ),
     44 =>
         array (
             'id' => 45,
             'permission_name' => '附件管理',
             'parent_id' => 28,
             'route' => '/attactments',
             'icon' => 'folder-open',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'attactments',
             'component' => 'attachment',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 10,
             'created_at' => '2020-04-21 18:01:42',
             'updated_at' => '2020-04-21 19:02:31',
             'deleted_at' => 0,
         ),
     45 =>
         array (
             'id' => 46,
             'permission_name' => '列表',
             'parent_id' => 45,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'attachments@index',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 18:02:15',
             'updated_at' => '2020-04-21 18:02:15',
             'deleted_at' => 0,
         ),
     46 =>
         array (
             'id' => 47,
             'permission_name' => '删除',
             'parent_id' => 45,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'attachments@delete',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 18:02:35',
             'updated_at' => '2020-04-21 18:02:35',
             'deleted_at' => 0,
         ),
     47 =>
         array (
             'id' => 48,
             'permission_name' => '上传图片',
             'parent_id' => 45,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'upload@image',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:01:59',
             'updated_at' => '2020-04-21 19:01:59',
             'deleted_at' => 0,
         ),
     48 =>
         array (
             'id' => 49,
             'permission_name' => '上传文件',
             'parent_id' => 45,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'upload@file',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:02:19',
             'updated_at' => '2020-04-21 19:02:19',
             'deleted_at' => 0,
         ),
     49 =>
         array (
             'id' => 50,
             'permission_name' => '配置管理',
             'parent_id' => 28,
             'route' => '/system/config',
             'icon' => 'setting',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'config',
             'component' => 'config',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 9,
             'created_at' => '2020-04-21 19:03:11',
             'updated_at' => '2020-04-21 19:08:44',
             'deleted_at' => 0,
         ),
     50 =>
         array (
             'id' => 51,
             'permission_name' => '获取父级配置',
             'parent_id' => 50,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'config@parent',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:03:56',
             'updated_at' => '2020-04-21 19:03:56',
             'deleted_at' => 0,
         ),
     51 =>
         array (
             'id' => 52,
             'permission_name' => '存储',
             'parent_id' => 50,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'config@save',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:04:12',
             'updated_at' => '2020-04-21 19:04:12',
             'deleted_at' => 0,
         ),
     52 =>
         array (
             'id' => 53,
             'permission_name' => '获取',
             'parent_id' => 50,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'config:read',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:04:22',
             'updated_at' => '2020-04-21 19:04:22',
             'deleted_at' => 0,
         ),
     53 =>
         array (
             'id' => 54,
             'permission_name' => '登陆日志',
             'parent_id' => 28,
             'route' => '/system/log/operate',
             'icon' => 'export',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'loginLog',
             'component' => 'loginLog',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 5,
             'created_at' => '2020-04-21 19:05:50',
             'updated_at' => '2020-04-21 19:08:34',
             'deleted_at' => 0,
         ),
     54 =>
         array (
             'id' => 55,
             'permission_name' => '操作日志',
             'parent_id' => 28,
             'route' => '/system/log/login',
             'icon' => 'profile',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'operateLog',
             'component' => 'operateLog',
             'redirect' => '',
             'hide_children_in_menu' => 2,
             'keep_alive' => 1,
             'type' => 1,
             'sort' => 1,
             'created_at' => '2020-04-21 19:06:20',
             'updated_at' => '2020-04-21 19:08:26',
             'deleted_at' => 0,
         ),
     55 =>
         array (
             'id' => 56,
             'permission_name' => '列表',
             'parent_id' => 54,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'loginlog@list',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:06:46',
             'updated_at' => '2020-04-21 19:06:46',
             'deleted_at' => 0,
         ),
     56 =>
         array (
             'id' => 57,
             'permission_name' => '清空',
             'parent_id' => 54,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'loginlog@empty',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:07:01',
             'updated_at' => '2020-04-21 19:07:01',
             'deleted_at' => 0,
         ),
     57 =>
         array (
             'id' => 58,
             'permission_name' => '列表',
             'parent_id' => 55,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'operatelog@list',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:07:26',
             'updated_at' => '2020-04-21 19:07:26',
             'deleted_at' => 0,
         ),
     58 =>
         array (
             'id' => 59,
             'permission_name' => '清空',
             'parent_id' => 55,
             'route' => '',
             'icon' => '',
             'module' => 'system',
             'creator_id' => 1,
             'method' => 'get',
             'permission_mark' => 'operatelog@empty',
             'component' => '',
             'redirect' => '',
             'hide_children_in_menu' => 1,
             'keep_alive' => 1,
             'type' => 2,
             'sort' => 1,
             'created_at' => '2020-04-21 19:07:46',
             'updated_at' => '2020-04-21 19:07:46',
             'deleted_at' => 0,
         ),
 ];
    }
}
